@@ -2,22 +2,19 @@ import types
 import logging
 
 try:
-    from django.db.models.fields import DateField
-    from django.db.models.fields.related import ForeignKey
     from django.db.models.loading import get_models, get_app
-    from django.core.serializers import serialize
-    from django.utils.simplejson import dumps, loads, JSONEncoder
-    from django.db import connection, DEFAULT_DB_ALIAS
     from django.conf import settings
+    from django.db import connection
     from django.core.exceptions import ObjectDoesNotExist
-    DJANGO_SUPPORT = True    
+    DJANGO_SUPPORT = True
 except ImportError:
     DJANGO_SUPPORT = False
-      
-ITEM_LIMIT = 1000 # How many items to cache before forcing an executemany.
-PARAMTOKEN = '%s' # 
-PK_ID = 'id' # default name of primary key field
-CLEAN_HOUSE = True # To avoid crashing the django-debug-toolbar, Thanks https://bitbucket.org/ringemup :-) !!
+
+ITEM_LIMIT = 1000  # How many items to cache before forcing an executemany.
+PARAMTOKEN = '%s'
+PK_ID = 'id'  # default name of primary key field
+CLEAN_HOUSE = True  # To avoid crashing the django-debug-toolbar,
+                    # Thanks https://bitbucket.org/ringemup :-) !!
 
 # a mapping of different database adapters/drivers, needed to handle different
 # quotations/escaping of sql fields, see the quote-method.
@@ -29,13 +26,14 @@ _DBNAME_MAP = {
     'pysqlite2': 'sqlite'
     }
 
+
 class TableObject(object):
     """
     This class holds information about a table object, its primary key, fields
     and lists for cached updates and inserts related to this table.
     """
 
-    def __init__(self, tablename, fields, pk = PK_ID):
+    def __init__(self, tablename, fields, pk=PK_ID):
         self.tablename = tablename
         self.fields = fields
         self.pk = pk
@@ -50,7 +48,7 @@ class TableObject(object):
         if values.get(self.pk, None) != None:
             self.update_items.append(values)
         else:
-            if values.has_key(self.pk) and not values.get(self.pk):
+            if self.pk in values and not values.get(self.pk):
                 del values[self.pk]
             self.insert_items.append(values)
 
@@ -58,32 +56,37 @@ class TableObject(object):
     def Count(self):
         return len(self.update_items) + len(self.insert_items)
 
-class ObjectNotRegistered(Exception): 
+
+class ObjectNotRegistered(Exception):
     """
     The model or table are not registered.
     """
     pass
 
+
 class DseException(Exception):
     action = 'unknown'
-    
+
     def __init__(self, exception, table, sql, params):
-        
+
         self.table = table
         self.sql = sql
         self.params = params
         self.exception = exception
-            
+
     def __str__(self):
         return "DseException.%sError on table %s.\nSQL: %s.\nNumber of params: %s.\nException: %s" % \
                (self.action, self.table, self.sql, len(self.params), self.exception)
-    
+
+
 class InsertManyException(DseException):
     action = 'Insert'
-    
+
+
 class UpdateManyException(DseException):
     action = 'UpdateMany'
-    
+
+
 class UpdateOneException(DseException):
     action = 'UpdateOne'
 
@@ -91,12 +94,13 @@ class UpdateOneException(DseException):
         return "DseException.%sError on table %s.\nSQL: %s.\nParams: %s.\nException: %s" % \
                (self.action, self.table, '\n'.join(self.sql), self.params, self.exception)
 
+
 class DelayedSqlExecutor(object):
     """
     The parent class. Not used directly. Better docs coming. I promise.
     """
 
-    def __init__(self, cursor, item_limit = ITEM_LIMIT, paramtoken = PARAMTOKEN):
+    def __init__(self, cursor, item_limit=ITEM_LIMIT, paramtoken=PARAMTOKEN):
         self.cursor = cursor
         self.item_limit = item_limit
         self.paramtoken = paramtoken
@@ -106,7 +110,7 @@ class DelayedSqlExecutor(object):
         self.records_processed = 0
         self.connection = cursor.connection
 
-    def add_object(self, tablename, pk = PK_ID, keyname = None):
+    def add_object(self, tablename, pk=PK_ID, keyname=None):
         """
         Adds a tablename to the internal list of tables, find its columns, storing
         those as well.
@@ -123,11 +127,11 @@ class DelayedSqlExecutor(object):
             logging.debug("AddObject: %s. Fields = %s" % (tablename, fields))
 
         self.registered_objects[keyname] = TableObject(tablename, fields, pk)
-    
+
     @property
     def TotalItemCount(self):
         total_items = 0
-        for k,v in self.registered_objects.items():
+        for k, v in self.registered_objects.items():
             total_items += v.Count
         return total_items
 
@@ -138,7 +142,7 @@ class DelayedSqlExecutor(object):
         to = self.registered_objects.get(tablename, None)
         if not to:
             raise ObjectNotRegistered(tablename)
-        
+
         if self.TotalItemCount >= self.item_limit:
             self.execute_sql()
 
@@ -149,9 +153,9 @@ class DelayedSqlExecutor(object):
         """
         Tries to determine what kind of database we are using, to later on use
         the correct escaping/quotation.
-        """        
-        assert(hasattr(self.cursor, 'connection'), \
-               'cursor object does not have a connection attribute. Cannot determine database type without it.')
+        """
+        assert hasattr(self.cursor, 'connection'), \
+               'cursor object does not have a connection attribute. Cannot determine database type without it.'
         mod = self.cursor.connection.__class__.__module__.split('.', 1)[0]
         return _DBNAME_MAP.get(mod)
 
@@ -161,12 +165,12 @@ class DelayedSqlExecutor(object):
         if self.get_dbname() == 'postgres':
             return '"%s"' % field
         return '`%s`' % field
-        
+
     def execute_sql(self):
         """
         Executes all cached sql statements, both updates and inserts.
         """
-        for k,v in self.registered_objects.items():
+        for k, v in self.registered_objects.items():
             tablename = self.registered_objects[k].tablename
             if v.update_items:
                 params_for_executemany = []
@@ -179,7 +183,7 @@ class DelayedSqlExecutor(object):
                     else:
                         found_all_fields = True
                         for field in v.fields:
-                            if not items.has_key(field):
+                            if not field in items:
                                 found_all_fields = False
                                 break
 
@@ -203,7 +207,7 @@ class DelayedSqlExecutor(object):
                     for fieldname in v.fields:
                         if fieldname == v.pk:
                             continue
-                        if items.has_key(fieldname):
+                        if fieldname in items:
                             m.append(items[fieldname])
                         else:
                             m.append(None)
@@ -215,7 +219,7 @@ class DelayedSqlExecutor(object):
                         for f in fieldvalues:
                             logging.debug(str(f))
 
-                if fieldvalues:                            
+                if fieldvalues:
                     self.sql_calls += 1
                     try:
                         self.cursor.executemany('\n'.join(sql), fieldvalues)
@@ -240,16 +244,15 @@ class DelayedSqlExecutor(object):
                         logging.debug("Executing update: %s" % '\n'.join(sql))
                         for f in fieldvalues:
                             logging.debug(str(f))
-                            
+
                     self.sql_calls += 1
                     try:
                         self.cursor.execute('\n'.join(sql), fieldvalues)
                         self.clean_house()
                     except Exception, e:
-                        raise UpdateOneException(e, tablename, sql, fieldvalues)                        
+                        raise UpdateOneException(e, tablename, sql, fieldvalues)
 
             if v.insert_items:
-                fieldnames = []                
                 sql = 'insert into %s (%s) values (%s)' % \
                     (v.tablename, ', '.join([self.quote(f) for f in v.fields if f != v.pk]), \
                       ', '.join([self.paramtoken for f in v.fields if f != v.pk]))
@@ -259,7 +262,7 @@ class DelayedSqlExecutor(object):
                     self.records_processed += 1
                     m = []
                     for fieldname in v.fields:
-                        if items.has_key(fieldname):
+                        if fieldname in items:
                             m.append(items[fieldname])
                         elif fieldname != v.pk:
                             m.append(None)
@@ -283,7 +286,7 @@ class DelayedSqlExecutor(object):
         This method removes the last query from the list of queries stored in the django connection
         object. The django-debug-toolbar modifies that list and if we leave our dse based query lying around
         it will cause the debug-toolbar to crash.
-        
+
         To disable this feature set dse.CLEAN_HOUSE = False.
         This method might later on be used for other things as well.
         """
@@ -291,10 +294,10 @@ class DelayedSqlExecutor(object):
             if self.debug:
                 logging.debug("DSE cleaning house: removing the last query from the list of queries in the connection object.")
             if hasattr(self, 'connection'):
-                if hasattr(self.connection, 'queries'):                
+                if hasattr(self.connection, 'queries'):
                     self.connection.queries = self.connection.queries[:-1]
-    
-    def get_items(self, tablename, where = None, order_by = None):
+
+    def get_items(self, tablename, where=None, order_by=None):
         """
         This is equal to django`s model.objects.values().
         """
@@ -311,7 +314,7 @@ class DelayedSqlExecutor(object):
             assert len(keys) == len(result), "Number of fields and returned columns does not match."
             for i in range(0, len(keys)):
                 result_dict[keys[i]] = result[i]
-            yield result_dict                
+            yield result_dict
 
     def flush(self):
         "Clears cache, executes cached sql statements."
@@ -349,11 +352,11 @@ def model_to_dict(obj, exclude_models=['AutoField', 'ForeignKey',  'OneToOneFiel
             field = getattr(obj, field_name)
         except ObjectDoesNotExist:
             continue
- 
+
         if field.__class__.__name__ in ['RelatedManager', 'ManyRelatedManager']:
             if field.model.__name__ in exclude_models:
                 continue
- 
+
             if field.__class__.__name__ == 'ManyRelatedManager':
                 exclude_models.append(obj.__class__.__name__)
             subtree = []
@@ -364,25 +367,26 @@ def model_to_dict(obj, exclude_models=['AutoField', 'ForeignKey',  'OneToOneFiel
                     subtree.append(value)
             if subtree:
                 tree[field_name] = subtree
- 
+
             continue
- 
+
         field = obj._meta.get_field_by_name(field_name)[0]
         if field.__class__.__name__ in exclude_models:
             continue
- 
+
         if field.__class__.__name__ == 'RelatedObject':
             exclude_models.append(field.model.__name__)
             tree[field_name] = model_to_dict(getattr(obj, field_name), \
                 exclude_models=exclude_models)
             continue
- 
+
         value = getattr(obj, field_name)
         if value:
             tree[field_name] = value
- 
+
     return tree
 
+
 def get_defaultvalue_for_field_from_model(model, field):
     """
     Get default value, if any, for a specified field in a specified model.
@@ -398,18 +402,19 @@ def get_defaultvalue_for_field_from_model(model, field):
                     return None
             return f.default
     return None
-    
+
+
 class DelayedExecutor(DelayedSqlExecutor):
     """
     A Django specific version of the DelayedSqlExecutor.
     """
 
-    def __init__(self, item_limit = ITEM_LIMIT, paramtoken = PARAMTOKEN, debug = True):
+    def __init__(self, item_limit=ITEM_LIMIT, paramtoken=PARAMTOKEN, debug=True):
         if not DJANGO_SUPPORT:
             raise Exception('No django support.')
-        
+
         cursor = connection.cursor()
-        super(DelayedExecutor, self ).__init__(cursor, item_limit, paramtoken)
+        super(DelayedExecutor, self).__init__(cursor, item_limit, paramtoken)
         self.connection = connection
         self.debug = debug
 
@@ -418,52 +423,53 @@ class DelayedExecutor(DelayedSqlExecutor):
         Produces a dictionary with fieldnames from a Django model as keys.
         If any field has defined a default value it will be set in the dictionary.
         """
-        
+
         result = {}
         for key in self.registered_objects[model._meta.object_name].fields:
             result[key] = get_defaultvalue_for_field_from_model(model, key)
         return result
-    
-    def add_objects_from_app(self, app_name, model_name = None):
+
+    def add_objects_from_app(self, app_name, model_name=None):
         "Adds tables found in models related to a specified app or for just one model if the model_name is specified."
         if not DJANGO_SUPPORT:
             raise Exception('No django support.')
-        
+
         for model in get_models(get_app(app_name)):
             if model_name and model_name != model._meta.object_name:
                 continue
-            
+
             self.add_model(model)
 
     def add_model(self, model):
         "Adds a table to insert/update based on a Django model"
         if not DJANGO_SUPPORT:
             raise Exception('No django support.')
-        
-        if not self.registered_objects.has_key(model._meta.object_name):
-            self.add_object(model._meta.db_table, pk = model._meta.pk.name, keyname = model._meta.object_name)
-        
+
+        if not model._meta.object_name in self.registered_objects:
+            self.add_object(model._meta.db_table, pk=model._meta.pk.name, keyname=model._meta.object_name)
+
     def add_item(self, model, values):
         "Adds a dictionary with values to insert/update for a specific model."
         if not DJANGO_SUPPORT:
             raise Exception('No django support.')
         super(DelayedExecutor, self).add_item(model._meta.object_name, values)
 
+
 class ModelDelayedExecutor(DelayedExecutor):
     """
     A helper-class for working with a specific Django model and DSE.
     """
-    def __init__(self, model, item_limit = ITEM_LIMIT, paramtoken = PARAMTOKEN, debug = True):
-        
+    def __init__(self, model, item_limit=ITEM_LIMIT, paramtoken=PARAMTOKEN, debug=True):
+
         if not DJANGO_SUPPORT:
             raise Exception('No django support.')
 
-        super(ModelDelayedExecutor, self ).__init__(item_limit, paramtoken)
+        super(ModelDelayedExecutor, self).__init__(item_limit, paramtoken)
         self.debug = debug
         self.model = model
         self.add_model(model)
         self.defaults = self.values_factory_for_model(self.model)
-        self.defaults_defined = len([v for v in self.defaults.values() if v])        
+        self.defaults_defined = len([v for v in self.defaults.values() if v])
         self.pk = self.registered_objects[model._meta.object_name].pk
 
     def add_item(self, values):
@@ -477,7 +483,7 @@ class ModelDelayedExecutor(DelayedExecutor):
         else:
             final_values = {}
             if self.defaults_defined:
-                for k,v in self.defaults.items():
+                for k, v in self.defaults.items():
                     if callable(v):
                         final_values[k] = v()
                     else:
@@ -489,8 +495,8 @@ class ModelDelayedExecutor(DelayedExecutor):
         "This method will execute the sql statement. No caching."
         self.add_item(values)
         self.flush()
-        
-    def get_items(self, where = None, order_by = None):
+
+    def get_items(self, where=None, order_by=None):
         """
         Returns a generator for records related to this model.
         Can be filtered using the where-argument, ex. age < 20 and
@@ -511,17 +517,18 @@ class ModelDelayedExecutor(DelayedExecutor):
         """
         return self.values_factory_for_model(self.model)
 
+
 def patch_models():
     """
     This method will monkey patch all models in installed apps to expose a dse attribute.
     """
-    assert(hasattr(settings, 'DATABASES') or hasattr(settings, 'DATABASE'), "Database information not found in settings.")
-    assert(len(settings.DATABASES.keys()) > 0, "No database has been configured.")
+    assert hasattr(settings, 'DATABASES') or hasattr(settings, 'DATABASE'), "Database information not found in settings."
+    assert len(settings.DATABASES.keys()) > 0, "No database has been configured."
     # So far we only monkey-patch models if one database has been configured.
     if len(settings.DATABASES.keys()) != 1:
         logging.warning("DSE has not monkey-patched any models because more than one database has been configured.")
         return []
-        
+
     result = []
     for model in get_models():
         #if not model._meta.managed:
@@ -532,28 +539,29 @@ def patch_models():
     logging.debug("Monkey patched %s models." % len(result))
     return result
 
+
 class BasicModelFactory:
     """
     This class will probably be removed for version 1.0.0.
     """
-    
-    def __init__(self):        
+
+    def __init__(self):
         self.models = []
         for model, dex in patch_models():
             self.models.append(dex)
             setattr(self, model._meta.object_name, dex)
-            
+
     def flush(self):
         for model in self.models:
-            assert(isinstance(model, ModelDelayedExecutor), 'Expected object to be ModelDelayedExecutor.')
-            assert(hasattr(model, 'flush'), 'Expected a flush method for ModelDelayedExecutor.')
+            assert isinstance(model, ModelDelayedExecutor), 'Expected object to be ModelDelayedExecutor.'
+            assert hasattr(model, 'flush'), 'Expected a flush method for ModelDelayedExecutor.'
             model.flush()
 
-    def close():
+    def close(self):
         self.flush()
 
     def __exit__(self, type, value, traceback):
         self.close()
 
     def __enter__(self):
-        return self
\ No newline at end of file
+        return self
